@@ -1,7 +1,7 @@
 from math import floor, log10
 
 
-def int_exponent(x):
+def int_exp(x):
     return floor(log10(abs(x)))
 
 
